GradientPacket class

If a list of colors and list of stops makes a PrimitiveGradient, does this GradientPacket constitute a supergradient?

Annotations

Constructors

GradientPacket(Gradient a, Gradient b, double t)
If a list of colors and list of stops makes a PrimitiveGradient, does this GradientPacket constitute a supergradient?
const

Properties

a → Gradient
A Gradient that this GradientPacket stores and represents.
final
b → Gradient
A Gradient that this GradientPacket stores and represents.
final
begin → AlignmentGeometry
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
center → AlignmentGeometry
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
distance → double
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
end → AlignmentGeometry
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
endAngle → double
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
focal → AlignmentGeometry?
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
focalRadius → double
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
gradient → Gradient
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
hashCode → int
The hash code for this object.
no setterinherited
radius → double
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadeFactor → double
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
shadeFunction → ColorArithmetic
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
softness → double
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
startAngle → double
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
t → double
The keyframe for this GradientPacket for retrieving the properties of these respective a & b Gradients using an appropriate lerp() method.
final
tileMode → TileMode
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter
transform → GradientTransform?
Returns the interpolation of this Gradient / Gradient-subclass property at keyframe t for gradients a and b.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited