Maths class abstract

A few options for functions that fulfill the StopsArithmetic definition.

Constructors

Maths()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

addition(double s, double f) → double
Add the provided animation value f to the provided stop s, claming between 0..1.
division(double s, double f) → double
Divide the provided stop s by the provided animation factor f, claming between 0..1.
multiplication(double s, double f) → double
Multiply the provided stop s by the provided animation factor f, claming between 0..1.
none(double s, double f) → double
Perform no maths and simply return the provided stop s.
subtraction(double s, double f) → double
Subtract the provided animation value f from the provided stop s, claming between 0..1.